
# Type: update date


date on which thing was updated. This can be applied to nodes or edges

URI: [biolink:update_date](https://w3id.org/biolink/vocab/update_date)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [Date](types/Date.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)
